==> causeway-bom-2.1.0-source-release.zip: causeway-bom-2.1.0/persistence/commons/src/main/java/org/apache/causeway/persistence/commons/integration/version/EntityVersionAccessorDefault.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.persistence.commons.integration.version;

import javax.annotation.Priority;
import javax.inject.Inject;

import org.springframework.stereotype.Service;

import org.apache.causeway.applib.annotation.PriorityPrecedence;
import org.apache.causeway.core.metamodel.facets.object.entity.EntityFacet;
import org.apache.causeway.core.metamodel.object.ManagedObject;
import org.apache.causeway.core.metamodel.objectmanager.ObjectManager;

import lombok.RequiredArgsConstructor;

@Service
@Priority(PriorityPrecedence.LAST)
@RequiredArgsConstructor(onConstructor_ = {@Inject})
public class EntityVersionAccessorDefault implements EntityVersionAccessor {

    private final ObjectManager objectManager;

    @Override
    public Object versionOf(Object domainObject) {
        ManagedObject managedObject = objectManager.adapt(domainObject);
        EntityFacet facet = managedObject.getSpecification().getFacet(EntityFacet.class);
        if (facet != null) {
            return facet.versionOf(domainObject);
        }
        return null;
    }
}

==> causeway-bom-3.1.0-source-release.zip: causeway-bom-3.1.0/persistence/commons/src/main/java/org/apache/causeway/persistence/commons/integration/version/EntityVersionAccessorDefault.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.causeway.persistence.commons.integration.version;

import jakarta.annotation.Priority;
import jakarta.inject.Inject;

import org.springframework.stereotype.Service;

import org.apache.causeway.applib.annotation.PriorityPrecedence;
import org.apache.causeway.core.metamodel.facets.object.entity.EntityFacet;
import org.apache.causeway.core.metamodel.object.ManagedObject;
import org.apache.causeway.core.metamodel.objectmanager.ObjectManager;

import lombok.RequiredArgsConstructor;

@Service
@Priority(PriorityPrecedence.LAST)
@RequiredArgsConstructor(onConstructor_ = {@Inject})
public class EntityVersionAccessorDefault implements EntityVersionAccessor {

    private final ObjectManager objectManager;

    @Override
    public Object versionOf(final Object domainObject) {
        ManagedObject managedObject = objectManager.adapt(domainObject);
        EntityFacet facet = managedObject.getSpecification().getFacet(EntityFacet.class);
        if (facet != null) {
            return facet.versionOf(domainObject);
        }
        return null;
    }
}
